@@ -32,7 +32,7 @@ class File():
 
     Parameters
     ----------
-    path : str
+    path: str
         - path to the file/folder we wish to track
     '''
     def __init__(self, path):
@@ -186,10 +186,18 @@ class File():
 
     @property
     def stem(self) -> str:
+        '''
+        - the basename of the file/folder without the extension
+        - i.e. 'file' instead of 'file.txt'
+        '''
         return self.name if self.isdir else self.name.split('.')[0]
 
     @property
     def suffix(self) -> str:
+        '''
+        - the extension of the file, or blank if a folder
+        - i.e. '.txt'
+        '''
         return '.' + self.name.split('.')[-1] if not self.isdir else ''
 
     def copy(self, dest: str, overwrite: bool = False) -> object:
@@ -201,6 +209,7 @@ class File():
         ----------
         dest: str
             - folder to copy file/folder into
+
         overwrite: bool
             - whether to overwrite if the destination file/folder already exists
             - default: False
@@ -231,6 +240,7 @@ class File():
         ----------
         dest: str
             - folder to move file/folder into
+
         overwrite: bool
             - whether to overwrite if the destination file/folder already exists
             - default: False
@@ -314,6 +324,7 @@ def checkzip(path: str) -> bool:
     -------
     True
         - file exists and is valid
+
     False
         - file doesn't exist, possibly because we deleted it due to corruption
     '''
@@ -368,11 +379,13 @@ def copy(path: str, dest: str, overwrite: bool = False) -> str:
     ----------
     path: str
         - path to desired file/folder
+
     dest: str
         - path to destination folder (where we're copying into)
+
     overwrite: bool
         - whether to overwrite an existing file/folder
-        - merges directories, but overwrites files if they exist
+        - merges folders, but overwrites files if they exist
         - default: False
 
     Returns
@@ -386,11 +399,11 @@ def copy(path: str, dest: str, overwrite: bool = False) -> str:
         if new_path_exists and not overwrite:
             raise FileExistsError(f'destination file already exists: {new_path}')
         return sh.copy2(path, new_path)
-    if new_path_exists:  # copying directory
+    if new_path_exists:  # copying folder
         if overwrite:
-            return sh.copytree(path, new_path, dirs_exist_ok=True)  # overwriting dest dir
-        raise FileExistsError(f'destination directory already exists: {new_path}')
-    return sh.copytree(path, new_path)  # dest dir doesn't exist, good
+            return sh.copytree(path, new_path, dirs_exist_ok=True)  # overwriting dest folder
+        raise FileExistsError(f'destination folder already exists: {new_path}')
+    return sh.copytree(path, new_path)  # dest folder doesn't exist, good
 
 
 def delete(path: str, force: bool = False) -> None:
@@ -401,6 +414,7 @@ def delete(path: str, force: bool = False) -> None:
     ----------
     path: str
         - path to file/folder
+
     force: bool
         - whether to try `shutil.rmtree() <https://docs.python.org/3/library/shutil.html#shutil.rmtree>`_ to delete a folder and its contents
         - default: False
@@ -526,9 +540,11 @@ def listdir(path: str = '.', dirs: bool = True, files: bool = True) -> tuple:
     path: str
         - folder to search in
         - default: current working directory
+
     dirs: bool
         - whether to list folders
         - default: True
+
     files: bool
         - whether to list files
         - default: True
@@ -542,7 +558,7 @@ def listdir(path: str = '.', dirs: bool = True, files: bool = True) -> tuple:
     dirs = bool(dirs)
     files = bool(files)
     if not os.path.exists(path):
-        raise FileNotFoundError(f'not found: {path}')
+        return ()
     result = []
     for child in os.listdir(path):
         child = joinpath(path, child)
@@ -562,11 +578,14 @@ def log(path: str, msg: str, ts: bool = True, ts_args: tuple = (1, 0, 1, 1, 1, 0
     ----------
     path: str
         - path to desired log file
+
     msg: str
         - message to log
+
     ts: bool
         - whether to include timestamp
         - default: True
+
     ts_args: iterable
         - arguments to pass to :func:`py416.timestamp`
         - default return example: [2022-08-19 13:24:54 -06:00]
@@ -600,6 +619,7 @@ def makedirs(*dirs, ignore_errors: bool = True) -> tuple:
     dirs
         - str: path to folder
         - iterable: nestings of lists and tuples with folder paths
+
     ignore_errors: bool
         - whether to catch all Exceptions from :func:`os.makedirs()`
         - useful to create as many of the requested folders as possible
@@ -638,9 +658,11 @@ def makefile(path: str, msg: str = '', overwrite: bool = False) -> str:
     ----------
     path: str
         - path to desired new file
+
     msg: str
         - text to put in the file
         - default: nothing
+
     overwrite: bool
         - whether to overwrite a file if it already exists
         - default: False
@@ -675,11 +697,13 @@ def move(path: str, dest: str, overwrite: bool = False) -> str:
     ----------
     path: str
         - path to desired file/folder
+
     dest: str
         - path to destination folder (where we're moving into)
+
     overwrite: bool
         - whether to overwrite an existing file/folder
-        - merges directories, but overwrites files if they exist
+        - merges folders, but overwrites files if they exist
         - default: False
 
     Returns
@@ -690,16 +714,18 @@ def move(path: str, dest: str, overwrite: bool = False) -> str:
     new_path = f'{dest}/{os.path.basename(path)}'
     new_path_exists = os.path.exists(new_path)
     if os.path.isfile(path):  # moving file
-        if new_path_exists and not overwrite:
-            raise FileExistsError(f'destination file already exists: {new_path}')
+        if new_path_exists:
+            if not overwrite:
+                raise FileExistsError(f'destination file already exists: {new_path}')
+            delete(new_path)  # deleting dest file to overwrite it
         return sh.move(path, dest)
-    if new_path_exists:  # moving directory
+    if new_path_exists:  # moving folder
         if overwrite:
-            result = sh.copytree(path, new_path, dirs_exist_ok=True)  # overwriting dest dir
+            result = sh.copytree(path, new_path, dirs_exist_ok=True)  # overwriting dest folder
             delete(path, force=True)  # deleting original (we're doing copy->delete manually)
             return result
-        raise FileExistsError(f'destination directory already exists: {new_path}')
-    return sh.move(path, dest)  # dest dir doesn't exist, good
+        raise FileExistsError(f'destination folder already exists: {new_path}')
+    return sh.move(path, dest)  # dest folder doesn't exist, good
 
 
 def parent(path: str) -> str:
@@ -735,6 +761,7 @@ def rename(path: str, name: str) -> str:
     ----------
     path: str
         - path to file/folder to be renamed
+
     name: str
         - new basename for file/folder (not path)
 
@@ -762,6 +789,7 @@ def rmdir(path: str, delroot: bool = True) -> int:
     ----------
     path: str
         - folder path to delete within
+
     delroot: bool
         - whether to delete the folder specified as well
         - default: True
@@ -792,13 +820,13 @@ def rmdir(path: str, delroot: bool = True) -> int:
 def splitpath(path: str) -> tuple:
     '''
     - splits a path string into its parts
-    
+
     Parameters
     ----------
     path: str
         - path
         - can be absolute or relative
-    
+
     Returns
     -------
     tuple[str]
@@ -846,11 +874,12 @@ def splitpath(path: str) -> tuple:
 def unzip(path: str, remove: bool = False) -> None:
     '''
     - unzips archive files of type: (.7z, .gz, .rar, .tar, .zip)
-    
+
     Parameters
     ----------
     path: str
         - path to archive file
+
     remove: bool
         - whether to delete archive after unzipping
         - default: False
@@ -877,16 +906,17 @@ def unzipdir(path: str, ignore_errors: bool = True) -> int:
     - unzips all archives in a folder (only 1st level) until it is unable to continue
     - deletes all archives as it unzips
     - supports archives of type: (.7z, .gz, .rar, .tar, .zip)
-    
+
     Parameters
     ----------
     path: str
         - folder containing archive files
+
     ignore_errors: bool
         - whether to catch all Exceptions in unzipping
         - useful to unzip everything possible in the directory
         - default: True
-    
+
     Returns
     -------
     int
